@@ -1,5 +1,7 @@
 """Inels light class for iNels BUS."""
 
+from pyinels.device.pyBase import pyBase
+
 from pyinels.const import (
     RANGE_BRIGHTNESS,
     ATTR_SWITCH_ON,
@@ -10,35 +12,24 @@ MIN_RANGE = RANGE_BRIGHTNESS[0]
 MAX_RANGE = RANGE_BRIGHTNESS[1]
 
 
-class pyLight:
+class pyLight(pyBase):
     """Inels class based on InelsDevice."""
 
     def __init__(self, device):
         """Initialize object."""
-        self.__device = device
-        self.__device.observe()
-        self.__has_brightness = isinstance(self.__device.value, float)
+        super().__init__(device)
+        self.__has_brightness = isinstance(
+            self._device.value[self._device.id], float)
 
     @property
     def state(self):
         """State of the light."""
         if self.has_brightness:
-            return (True if self.__device.value > MIN_RANGE else False)
+            return (True if self._device.value[self._device.id]
+                    > MIN_RANGE else False)
 
-        val = str(self.__device.value)
-        attr = ATTR_SWITCH_ON
-
-        return (True if val == attr else False)
-
-    @property
-    def name(self):
-        """Name of the light."""
-        return self.__device.title
-
-    @property
-    def unique_id(self):
-        """Unique id of the device."""
-        return self.__device.id
+        return (True if self._device.value[self._device.id]
+                == ATTR_SWITCH_ON else False)
 
     @property
     def has_brightness(self):
@@ -49,39 +40,27 @@ class pyLight:
         """Set brightness of the light."""
         if (self.has_brightness
                 and (value >= MIN_RANGE and value <= MAX_RANGE)):
-            self.__device.write_value(value)
+            self._device.write_value(value)
 
     def brightness(self):
         """Return the brightness value."""
         if self.has_brightness is True:
-            return self.__device.value
+            return self._device.value[self._device.id]
 
         return None
 
     def turn_off(self):
         """Turn off the light."""
         if self.has_brightness is True:
-            self.__device.write_value(MIN_RANGE)
+            self._device.write_value(MIN_RANGE)
             return
 
-        self.__device.write_value(ATTR_SWITCH_OFF)
+        self._device.write_value(ATTR_SWITCH_OFF)
 
     def turn_on(self):
         """Turn on the light."""
         if self.has_brightness is True:
-            self.__device.write_value(MAX_RANGE)
+            self._device.write_value(MAX_RANGE)
         else:
             # set device value to 0 when turn off and to 1 when turn on
-            self.__device.write_value(ATTR_SWITCH_ON)
-
-    def update(self):
-        """Update data on the device."""
-        return self.__device.observe()
-
-    def __repr__(self):
-        """Object representation."""
-        state = "on" if self.state else "off"
-        return "<Light #{} - " \
-            "title: {}, " \
-            "state: {}" \
-            ">".format(self.__device.id, self.__device.title, state)
+            self._device.write_value(ATTR_SWITCH_ON)
