@@ -3,9 +3,11 @@ from pyinels.const import ATTR_SWITCH
 
 from tests.const_test import (
     TEST_API_CLASS_NAMESPACE,
+    TEST_API_ROOM_DEVICES,
+    TEST_API_READ_DATA,
     TEST_HOST,
     TEST_PORT,
-    TEST_RAW_DEVICES,
+    TEST_RAW_SWITCH,
     TEST_VERSION
 )
 
@@ -15,8 +17,11 @@ from pyinels.device.pySwitch import pySwitch
 from unittest.mock import patch
 from unittest import TestCase
 
-GARAGE_RETURN_OFF = {'ZA_01_GARAGE': 0}
-GARAGE_RETURN_ON = {'ZA_01_GARAGE': 1}
+SWITCH_ID = "ZAS_13A_Loznice"
+SWITCH_NAME = "Zas loznice"
+
+SWITCH_RETURN_OFF = {SWITCH_ID: 0}
+SWITCH_RETURN_ON = {SWITCH_ID: 1}
 
 
 class PySwitchTest(TestCase):
@@ -26,10 +31,10 @@ class PySwitchTest(TestCase):
         """Setup all necesary instances and mocks."""
         self.patches = [
             patch(f'{TEST_API_CLASS_NAMESPACE}.ping', return_value=True),
-            patch(f'{TEST_API_CLASS_NAMESPACE}.getRoomDevicesRaw',
-                  return_value=TEST_RAW_DEVICES),
-            patch(f'{TEST_API_CLASS_NAMESPACE}._Api__readDeviceData',
-                  return_value=GARAGE_RETURN_OFF),
+            patch(f'{TEST_API_CLASS_NAMESPACE}.{TEST_API_ROOM_DEVICES}',
+                  return_value=TEST_RAW_SWITCH),
+            patch(f'{TEST_API_CLASS_NAMESPACE}.{TEST_API_READ_DATA}',
+                  return_value=SWITCH_RETURN_OFF),
             patch(f'{TEST_API_CLASS_NAMESPACE}._Api__writeValues',
                   return_value=None)
         ]
@@ -53,6 +58,8 @@ class PySwitchTest(TestCase):
     def test_state(self):
         """Test the state of the pySwitch."""
         s = self.switch
+
+        s.update()
         # the switch at the beggining should be turned off
         self.assertFalse(s.state)
 
@@ -63,24 +70,35 @@ class PySwitchTest(TestCase):
         self.assertIsNotNone(s.unique_id)
         self.assertIsNotNone(s.name)
 
+        self.assertEqual(s.unique_id, SWITCH_ID)
+        self.assertEqual(s.name, SWITCH_NAME)
+
     def test_turn_on(self):
         """Test turn on the switch."""
         s = self.switch
+
+        s.update()
         self.assertFalse(s.state)
 
-        with patch.object(self.api, '_Api__readDeviceData',
-                          return_value=GARAGE_RETURN_ON):
+        with patch.object(self.api, TEST_API_READ_DATA,
+                          return_value=SWITCH_RETURN_ON):
             s.turn_on()
+
+            s.update()
             self.assertTrue(s.state)
 
     def test_turn_off(self):
         """Test turn off the switch."""
         s = self.switch
 
-        with patch.object(self.api, '_Api__readDeviceData',
-                          return_value=GARAGE_RETURN_ON):
+        with patch.object(self.api, TEST_API_READ_DATA,
+                          return_value=SWITCH_RETURN_ON):
             s.turn_on()
+
+            s.update()
             self.assertTrue(s.state)
 
         s.turn_off()
+
+        s.update()
         self.assertFalse(s.state)
